/* 
	Copyright (C) 2014 Nicklas Nordborg

	This file is part of the Example Code Package for BASE.
	Available at http://baseplugins.thep.lu.se/
	BASE main site: http://base.thep.lu.se/
	
	This is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.
	
	The software is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
var ExampleToolbarButtons = function()
{
	var buttons = {};

	/**
		Executed once when the page is loaded. Typically
		used to bind events to fixed control elements.
	*/
	buttons.initPage = function()
	{
		// Bind event handlers to the toolbar buttons
		Buttons.addClickHandler('more-info-button', buttons.showMoreInfo);
		Buttons.addClickHandler('annotation-filter', buttons.annotationFilter);
	}
	
	/**
		An alternate approach to event binding. Usually used when the number
		of elements on a page is not known and the initPage method is of limited use.
		
		This method is called once for every element with class="auto-init".
		Check the autoInit parameter if something needs to be done.
	*/
	buttons.initElements = function(element, autoInit)
	{
		if (autoInit == 'click-me')
		{
			Buttons.addClickHandler(element, buttons.clickMe);
		}
	}

	buttons.clickMe = function(event)
	{
		var message = Data.get(event.currentTarget, 'message');
		alert(message);
	}
	
	buttons.showMoreInfo = function(event)
	{
		var itemType = Data.get(event.currentTarget, 'item-type');
		var itemId = Data.get(event.currentTarget, 'item-id');
		var url = Data.get(event.currentTarget, 'url');
		url += '?ID='+App.getSessionId();
		url += '&item_type=' + itemType;
		url += '&item_id='+itemId;
		Dialogs.openPopup(url, 'ItemInfo', 600, 400);
	}
	
	buttons.annotationFilter = function(event)
	{
		var itemType = Data.get(event.currentTarget, 'item-type');
		var url = Data.get(event.currentTarget, 'url');
		url += '?ID='+App.getSessionId();
		url += '&item_type=' + itemType;
		Dialogs.openPopup(url, 'AnnotationFilter', 450, 300);
	}
	
	return buttons;
}();

// Register the page and element initializer method with the BASE core
Doc.onLoad(ExampleToolbarButtons.initPage);
Doc.addElementInitializer(ExampleToolbarButtons.initElements);

